-- name: \\#8FB9CC\\[CS] Meina
-- description: Meina v1.0\nCreated and modeled by Oradimi.\n\nYou need the Character Select mod.\nType /char-select to select.

--[[
    API Documentation for Character Select can be found below:
    https://github.com/Squishy6094/character-select-coop/wiki/API-Documentation
]]

local MOD_VERSION = _G.charSelect.version_get()
local MAJOR, MINOR, PATCH = string.match(MOD_VERSION, "(%d+)%.(%d+)%.?(%d*)")
MAJOR, MINOR, PATCH = tonumber(MAJOR), tonumber(MINOR), tonumber(PATCH) or 0
local V1_8_OR_ABOVE = MAJOR > 1 or (MAJOR == 1 and MINOR >= 8)

local TEXT_MOD_NAME = "Meina"

-- MEINA --

local E_MODEL_MEINA = smlua_model_util_get_id("meina_geo")
local E_MODEL_MEINA_R = smlua_model_util_get_id("meina_geo_r")
local CAPTABLE_MEINA = {
    normal = smlua_model_util_get_id("meina_cap_geo"),
    wing = smlua_model_util_get_id("meina_wing_cap_geo"),
    metal = smlua_model_util_get_id("meina_metal_cap_geo"),
    metalWing = smlua_model_util_get_id("meina_metal_wing_cap_geo"),
}
local PALETTE_MEINA = nil
if V1_8_OR_ABOVE then
	PALETTE_MEINA = {
		[PANTS]  = "ffffff",
		[SHIRT]  = "6baec4",
		[GLOVES] = "383056",
		[SHOES]  = "6baec4",
		[HAIR]   = "9c9c9c",
		[SKIN]   = "88aeaf",
		[CAP]    = "383056",
	}
end
local VOICETABLE_MEINA = {
    [CHAR_SOUND_ATTACKED] = {'meina_hurt2.mp3', 'meina_kuh.mp3', 'meina_eh.mp3'},
	--[CHAR_SOUND_COUGHING1] = 'silent.mp3',
    --[CHAR_SOUND_COUGHING2] = 'silent.mp3',
	--[CHAR_SOUND_COUGHING3] = 'silent.mp3',
    [CHAR_SOUND_DOH] = 'meina_ah2.mp3', -- Bonk into walls
	--[CHAR_SOUND_DROWNING] = 'silent.mp3',
    [CHAR_SOUND_DYING] = {'meina_kuyashi2.mp3', 'meina_hurt3.mp3'},
    [CHAR_SOUND_EEUH] = {'meina_ledgegetup.mp3',}, -- Slow Get up from ledge
    --[CHAR_SOUND_GAME_OVER] = {'silent.mp3'},
    [CHAR_SOUND_GROUND_POUND_WAH] = {'meina_attack4.mp3', 'meina_attack1.mp3',},
    [CHAR_SOUND_HAHA] = {'meina_attack3.mp3', 'meina_yosh.mp3'}, -- Landing after backflip
    --[CHAR_SOUND_HAHA_2] = 'silent.mp3', -- Landing on Water after a fall
    --[CHAR_SOUND_HELLO] = 'silent.mp3',
    [CHAR_SOUND_HERE_WE_GO] = {'meina_yosh.mp3'}, -- Star Get + Obtaining Power-up
    [CHAR_SOUND_HOOHOO] = 'meina_attack3.mp3', -- 2nd Jump + Dive Attack
    [CHAR_SOUND_HRMM] = 'meina_yosh.mp3', -- Object Pick-up
    [CHAR_SOUND_IMA_TIRED] = 'meina_hmm2.mp3',
    [CHAR_SOUND_LETS_A_GO] = 'meina_letsgo.mp3', -- Level Select
    [CHAR_SOUND_MAMA_MIA] = 'meina_I_lost.mp3', -- Getting up after thrown out of level
	--[CHAR_SOUND_OKEY_DOKEY] = 'silent.mp3',
    [CHAR_SOUND_ON_FIRE] = {'meina_hurt1.mp3',}, -- Touch Fire
    [CHAR_SOUND_OOOF] = 'meina_ah2.mp3',
    [CHAR_SOUND_OOOF2] = 'meina_hurt2.mp3', -- Landing After a Bonk + Thrown out of level
    [CHAR_SOUND_PANTING] = {'meina_pant.mp3',}, -- Low Health
    --[CHAR_SOUND_PANTING_COLD] = 'silent.mp3',
    --[CHAR_SOUND_PRESS_START_TO_PLAY] = {'silent.mp3', 'silent.mp3'},
    [CHAR_SOUND_PUNCH_HOO] = {'meina_attack1.mp3',}, -- Kick
    [CHAR_SOUND_PUNCH_WAH] = 'meina_attack4.mp3', -- 2nd Punch
    [CHAR_SOUND_PUNCH_YAH] = 'meina_attack7.mp3', -- 1st Punch
    --[CHAR_SOUND_SNORING1] = 'silent.mp3',
    --[CHAR_SOUND_SNORING2] = 'silent.mp3',
    --[CHAR_SOUND_SNORING3] = {'silent.mp3', 'silent.mp3'},
    [CHAR_SOUND_SO_LONGA_BOWSER] = {'meina_attack2.mp3', 'meina_bowserthrow3.mp3'}, -- Bowser Throw
    [CHAR_SOUND_TWIRL_BOUNCE] = {'meina_attack2.mp3'}, -- Boing
    [CHAR_SOUND_UH] = 'meina_wah.mp3', -- Drop off of ledge
    [CHAR_SOUND_UH2] = {'meina_attack9.mp3',}, -- ???
    [CHAR_SOUND_UH2_2] = 'meina_are.mp3', -- Landing after Long Jump
    [CHAR_SOUND_WAAAOOOW] = 'meina_hurt1.mp3', -- Falling
    [CHAR_SOUND_WAH2] = 'meina_attack4.mp3', -- Throw Object
    [CHAR_SOUND_WHOA] = 'meina_huh.mp3', -- Ledge Grab
    [CHAR_SOUND_YAHOO] = {'meina_attack3a.mp3',}, -- Long Jump
    [CHAR_SOUND_YAHOO_WAHA_YIPPEE] = {'meina_attack2.mp3'}, -- 3rd Jump
    [CHAR_SOUND_YAH_WAH_HOO] = {'meina_attack9.mp3', 'meina_ah1.mp3', 'meina_atk6.mp3'}, -- 1st Jump
    --[CHAR_SOUND_YAWNING] = 'silent.mp3',
}

local TABLE_OF_VOICES = {
    VOICETABLE_MEINA
}

-- Function aliases
local cs_char_add = _G.charSelect.character_add
local cs_char_add_voice = _G.charSelect.character_add_voice
local cs_char_get_voice = _G.charSelect.character_get_voice
local cs_voice_sound = _G.charSelect.voice.sound
local cs_voice_snore = _G.charSelect.voice.snore
local cs_char_add_caps = _G.charSelect.character_add_caps
local cs_char_add_palette_preset = nil
if V1_8_OR_ABOVE then
	cs_char_add_palette_preset = _G.charSelect.character_add_palette_preset
end

if _G.charSelectExists then
    cs_char_add(
		"Meina",
		{
			"\"The Cave Witch\"",
			"Lives deep inside a cave with",
			"her cauldron and rocky friends."
		},
		"Oradimi",
		{r = 143, g = 185, b = 204},
		E_MODEL_MEINA, CT_MARIO, gTextures.mario_head
	)
	
	cs_char_add(
		"Meina (Recolor)",
		{
			"\"The Cave Witch\"",
			"Lives deep inside a cave with",
			"her cauldron and rocky friends.",
			"Can be recolored."
		},
		"Oradimi",
		{r = 143, g = 185, b = 204},
		E_MODEL_MEINA_R, CT_MARIO, gTextures.mario_head
	)

-- All Caps and Voices
	cs_char_add_caps(E_MODEL_MEINA, CAPTABLE_MEINA)
    cs_char_add_voice(E_MODEL_MEINA, VOICETABLE_MEINA)
	
	cs_char_add_caps(E_MODEL_MEINA_R, CAPTABLE_MEINA)
    cs_char_add_voice(E_MODEL_MEINA_R, VOICETABLE_MEINA)
	if V1_8_OR_ABOVE then
		cs_char_add_palette_preset(E_MODEL_MEINA_R, PALETTE_MEINA)
	end

    hook_event(HOOK_CHARACTER_SOUND, function (m, sound)
        for i = 1, #TABLE_OF_VOICES do
            if cs_char_get_voice(m) == TABLE_OF_VOICES[i] then return cs_voice_sound(m, sound) end
        end
    end)
    hook_event(HOOK_MARIO_UPDATE, function (m)
        for i = 1, #TABLE_OF_VOICES do
            if cs_char_get_voice(m) == TABLE_OF_VOICES[i] then return cs_voice_snore(m) end
        end
    end)
else
    djui_popup_create("\\#ffffdc\\\n"..TEXT_MOD_NAME.."\nRequires the Character Select Mod\nto use as a Library!\n\nPlease turn on the Character Select Mod\nand Restart the Room!", 6)
end